# `ml_indie_tools`, a collection of machine learning tools for low-resource research and experiments

[![License](http://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](LICENSE)
[![Docs](https://img.shields.io/badge/docs-stable-blue.svg)](https://domschl.github.io/ml-indie-tools/index.html)
[![PyPI version fury.io](https://badge.fury.io/py/ml-indie-tools.svg)](https://pypi.python.org/pypi/ml-indie-tools/)

**Note:** THIS LIBRARY IS UNFINISHED WORK-IN-PROGRESS

## Description


### `env_tools`

A collection of tools that allow moving machine learning projects between local hardware and colab instances.

#### Examples

```python
from ml_indie_tools.env_tools import MLEnv

ml_env = MLEnv(platform='tf', accelator='fastest')
```

### `Gutenberg_Dataset`

### `Text_Dataset`

### `ALU_Dataset`

## History

* (2021-12-26, 0.0.x) First pre-alpha versions published for testing purposes, not ready for use.

